@@ -18,9 +18,20 @@ import unicodedata
 
 import numpy as np
 
-from typing import *
 from abc import abstractmethod
 from tqdm import tqdm
+from typing import Any
+from typing import Set
+from typing import Dict
+from typing import List
+from typing import Type
+from typing import Union
+from typing import Generic
+from typing import TypeVar
+from typing import Callable
+from typing import Iterable
+from typing import Optional
+from typing import NamedTuple
 from argparse import Namespace
 from datetime import datetime
 from datetime import timedelta
@@ -90,7 +101,7 @@ def prepare_workplace_from(workplace: str, timeout: timedelta = timedelta(30)) -
                 stuff_delta = current_time - stuff_time
                 if stuff_delta > timeout:
                     print(
-                        f"{WARNING_PREFIX}{stuff} will be removed "
+                        f"{LoggingMixin.warning_prefix}{stuff} will be removed "
                         f"(already {stuff_delta} ago)"
                     )
                     shutil.rmtree(os.path.join(workplace, stuff))
@@ -309,6 +320,7 @@ def register_core(
     name: str,
     global_dict: Dict[str, type],
     *,
+    allow_duplicate: bool = False,
     before_register: Optional[Callable] = None,
     after_register: Optional[Callable] = None,
 ):
@@ -316,7 +328,7 @@ def register_core(
         if before_register is not None:
             before_register(cls)
         registered = global_dict.get(name)
-        if registered is not None:
+        if registered is not None and not allow_duplicate:
             print(
                 f"{LoggingMixin.warning_prefix}'{name}' has already registered "
                 f"in the given global dict ({global_dict})"
@@ -417,11 +429,21 @@ class WithRegister(Generic[T]):
         ]
 
     @classmethod
-    def register(cls, name: str) -> Callable[[Type[T]], Type[T]]:
+    def register(
+        cls,
+        name: str,
+        *,
+        allow_duplicate: bool = False,
+    ) -> Callable[[Type[T]], Type[T]]:
         def before(cls_: Type[T]) -> None:
             cls_.__identifier__ = name
 
-        return register_core(name, cls.d, before_register=before)
+        return register_core(
+            name,
+            cls.d,
+            allow_duplicate=allow_duplicate,
+            before_register=before,
+        )
 
     @classmethod
     def check_subclass(cls, name: str) -> bool:
